@@ -1,7 +1,7 @@
 aictab <-
   function(cand.set, modnames, sort = TRUE, c.hat = 1, second.ord = TRUE, nobs = NULL) {
     results <- NULL
-    known <- rep(0, 13) #create an identifier of class type other than lm, glm, multinom, polr, lme, gls, mer, unmarked, nls, or coxph
+    known <- rep(0, 14) #create an identifier of class type other than lm, glm, multinom, polr, lme, gls, mer, unmarked, nls, or coxph
     ##extract classes
     mod.class <- unlist(lapply(X = cand.set, FUN = class))
     ##check if all are identical
@@ -100,12 +100,19 @@ aictab <-
       known[12] <- 1
     }
 
+    ##determine if nlme
+    if(identical(check.class, c("nlme", "lme")))  {
+      results <- aictab.nlme(cand.set = cand.set, modnames = modnames, sort = sort,
+                             second.ord = second.ord, nobs = nobs)
+      known[13] <- 1
+    }
+
         
     ##warn if models are from a mixture of lm and lme model classes
     if(identical(sort(check.class), c("lm", "lme"))) {
       stop("\nFunction not appropriate for mixture of object classes:", "\n",
                "avoid mixing objects of classes \'lm\' and \'lme\'\n")
-      known[13] <- 1
+      known[14] <- 1
     }
 
 
